@@ -166,10 +166,10 @@ class Document(BaseDocument):
                 else:
                     dct = default
 
-            if req or dct is not None:
+            if dct is not None:
 
                 if typ is ObjectId and type(dct) is str:
-                    return ObjectId(dct)
+                    dct = ObjectId(dct)
 
                 if not type(dct) is typ:
                     raise TypeError
